==> glidertools-2022.12.13.tar.gz: glidertools-2022.12.13/docs/authors.md <==
Citing GliderTools
==================

[![](https://zenodo.org/badge/141922866.svg)](https://zenodo.org/badge/latestdoi/141922866)

If you would like to cite or reference Glider Tools, please use:

Gregor, L., Ryan-Keogh, T. J., Nicholson, S.-A., du Plessis, M., Giddy, I., & Swart, S. (2019). GliderTools: A Python Toolbox for Processing Underwater Glider Data. Frontiers in Marine Science, 6(December), 1–13. https://doi.org/10.3389/fmars.2019.00738


Project Contributors
--------------------

The following people have made contributions to the project (in alphabetical order by last name) and are considered "The GliderTools Developers". These contributors will be added as authors upon the next major release of GliderTools (i.e. new DOI release).
- [Dhruv Balwada](https://dhruvbalwada.github.io/) - University of Washington, USA. (ORCID: [0000-0001-6632-0187](https://orcid.org/0000-0001-6632-0187))
- [Julius Busecke](http://jbusecke.github.io/) -  Columbia University, USA. (ORCID: [0000-0001-8571-865X](https://orcid.org/0000-0001-8571-865X))
- [Isabelle Giddy](https://github.com/isgiddy/) - University of Cape Town: Cape Town, Western Cape, South Africa. (ORCID: [0000-0002-8926-3311](https://orcid.org/0000-0002-8926-3311))
- [Luke Gregor](https://github.com/lukegre) - Environmental Physics, ETH Zuerich: Zurich, Switzerland. (ORCID: [0000-0001-6071-1857](https://orcid.org/0000-0001-6071-1857))
- [Martin Mohrmann](https://github.com/MartinMohrmann) - Voice of the Ocean Foundation, Gothenburg, Sweden. (ORCID: [0000-0001-8056-4866](https://orcid.org/0000-0001-8056-4866))
- [Sarah-Anne Nicholson](https://github.com/sarahnicholson) - Council for Scientific and Industrial Research: Cape Town, South Africa. (ORCID: [0000-0002-1226-1828](https://orcid.org/0000-0002-1226-1828))
- [Marcel du Plessis](https://mduplessis.com) - University of Cape Town: Cape Town, Western Cape, South Africa. (ORCID: [0000-0003-2759-2467](https://orcid.org/0000-0003-2759-2467))
- [Callum Rollo](https://callumrollo.github.io/) -  University of East Anglia, UK. (ORCID: [0000-0002-5134-7886](https://orcid.org/0000-0002-5134-7886))
- [Tommy Ryan-Keogh](https://github.com/tjryankeogh) - Council for Scientific and Industrial Research: Cape Town, South Africa. (ORCID: [0000-0001-5144-171X](https://orcid.org/0000-0001-5144-171X))
- [Sebastiaan Swart](https://sebswart.com) - University of Gothenburg: Gothenburg, Sweden. (ORCID: [0000-0002-2251-8826](https://orcid.org/0000-0002-2251-8826))
- [Soeren Thomsen](https://github.com/soerenthomsen) - LOCEAN/IPSL/CNRS/Sorbonne University: Paris, France. (ORCID: [0000-0002-0598-8340](https://orcid.org/0000-0002-0598-8340))

==> glidertools-2023.7.25.tar.gz: glidertools-2023.7.25/docs/authors.md <==
Citing GliderTools
==================

[![](https://zenodo.org/badge/141922866.svg)](https://zenodo.org/badge/latestdoi/141922866)

If you would like to cite or reference Glider Tools, please use:

Gregor, L., Ryan-Keogh, T. J., Nicholson, S.-A., du Plessis, M., Giddy, I., & Swart, S. (2019). GliderTools: A Python Toolbox for Processing Underwater Glider Data. Frontiers in Marine Science, 6(December), 1–13. https://doi.org/10.3389/fmars.2019.00738


Project Contributors
--------------------

The following people have made contributions to the project (in alphabetical order by last name) and are considered "The GliderTools Developers". These contributors will be added as authors upon the next major release of GliderTools (i.e. new DOI release).
- [Dhruv Balwada](https://dhruvbalwada.github.io/) - University of Washington, USA. (ORCID: [0000-0001-6632-0187](https://orcid.org/0000-0001-6632-0187))
- [Julius Busecke](http://jbusecke.github.io/) -  Columbia University, USA. (ORCID: [0000-0001-8571-865X](https://orcid.org/0000-0001-8571-865X))
- [Isabelle Giddy](https://github.com/isgiddy/) - University of Cape Town: Cape Town, Western Cape, South Africa. (ORCID: [0000-0002-8926-3311](https://orcid.org/0000-0002-8926-3311))
- [Luke Gregor](https://github.com/lukegre) - Environmental Physics, ETH Zuerich: Zurich, Switzerland. (ORCID: [0000-0001-6071-1857](https://orcid.org/0000-0001-6071-1857))
- [Tom Hull](https://github.com/tomhull) - Centre for Environment Fisheries and Aquaculture Science: Lowestoft, UK. (ORCID: [0000-0002-1714-9317](https://orcid.org/0000-0002-1714-9317))
- [Martin Mohrmann](https://github.com/MartinMohrmann) - Voice of the Ocean Foundation, Gothenburg, Sweden. (ORCID: [0000-0001-8056-4866](https://orcid.org/0000-0001-8056-4866))
- [Sarah-Anne Nicholson](https://github.com/sarahnicholson) - Council for Scientific and Industrial Research: Cape Town, South Africa. (ORCID: [0000-0002-1226-1828](https://orcid.org/0000-0002-1226-1828))
- [Marcel du Plessis](https://mduplessis.com) - University of Cape Town: Cape Town, Western Cape, South Africa. (ORCID: [0000-0003-2759-2467](https://orcid.org/0000-0003-2759-2467))
- [Callum Rollo](https://callumrollo.github.io/) - Voice of the Ocean Foundation, Gothenburg, Sweden. (ORCID: [0000-0002-5134-7886](https://orcid.org/0000-0002-5134-7886))
- [Tommy Ryan-Keogh](https://github.com/tjryankeogh) - Council for Scientific and Industrial Research: Cape Town, South Africa. (ORCID: [0000-0001-5144-171X](https://orcid.org/0000-0001-5144-171X))
- [Sebastiaan Swart](https://sebswart.com) - University of Gothenburg: Gothenburg, Sweden. (ORCID: [0000-0002-2251-8826](https://orcid.org/0000-0002-2251-8826))
- [Soeren Thomsen](https://github.com/soerenthomsen) - LOCEAN/IPSL/CNRS/Sorbonne University: Paris, France. (ORCID: [0000-0002-0598-8340](https://orcid.org/0000-0002-0598-8340))
